@@ -1,6 +1,6 @@
 from django.core.management.base import BaseCommand
 from django.conf import settings
-from _generate_dubgger import generate_debugger
+from _generate_debugger import generate_debugger
 
 
 class Command(BaseCommand):
